16.153. cdist-type__sysctl(7) — cdist 6.9.8 documentation

# 16.153. cdist-type__sysctl(7)

## 16.153.1. NAME

cdist-type__sysctl - manage sysctl settings

## 16.153.2. DESCRIPTION

Manages permanent as well as runtime sysctl settings. Permament settings are set by managing entries in /etc/sysctl.conf. Runtime settings are set by directly calling the sysctl executable.

## 16.153.3. REQUIRED PARAMETERS

value

  The value to set for the given key (object_id)

## 16.153.4. EXAMPLES

    __sysctl net.ipv4.ip_forward --value 1

    # On some operating systems, e.g. NetBSD, to prevent an error if the
    # MIB style name does not exist (e.g. optional kernel components),
    # name and value can be separated by `?=`. The same effect can be achieved
    # in cdist by appending a `?` to the key:

    __sysctl ddb.onpanic? --value -1

## 16.153.5. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.153.6. COPYING

Copyright (C) 2014 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 or later (GPLv3+).